@@ -71,8 +71,8 @@ module Sass
       OPERATORS_REVERSE = Sass::Util.map_hash(OPERATORS) {|k, v| [v, k]}
 
       TOKEN_NAMES = Sass::Util.map_hash(OPERATORS_REVERSE) {|k, v| [k, v.inspect]}.merge(
-          :const => "variable (e.g. $foo)",
-          :ident => "identifier (e.g. middle)")
+        :const => "variable (e.g. $foo)",
+        :ident => "identifier (e.g. middle)")
 
       # A list of operator strings ordered with longer names first
       # so that `>` and `<` don't clobber `>=` and `<=`.
@@ -80,7 +80,7 @@ module Sass
 
       # A sub-list of {OP_NAMES} that only includes operators
       # with identifier names.
-      IDENT_OP_NAMES = OP_NAMES.select {|k, v| k =~ /^\w+/}
+      IDENT_OP_NAMES = OP_NAMES.select {|k, _v| k =~ /^\w+/}
 
       PARSEABLE_NUMBER = /(?:(\d*\.\d+)|(\d+))(?:[eE]([+-]?\d+))?(#{UNIT})?/
 
@@ -179,6 +179,13 @@ module Sass
         end
       end
 
+      # Returns the given character.
+      #
+      # @return [String]
+      def char(pos = @scanner.pos)
+        @scanner.string[pos, 1]
+      end
+
       # Returns the next token without moving the lexer forward.
       #
       # @return [Token] The next token
@@ -189,11 +196,10 @@ module Sass
       # Rewinds the underlying StringScanner
       # to before the token returned by \{#peek}.
       def unpeek!
-        if @tok
-          @scanner.pos = @tok.pos
-          @line = @tok.source_range.start_pos.line
-          @offset = @tok.source_range.start_pos.offset
-        end
+        return unless @tok
+        @scanner.pos = @tok.pos
+        @line = @tok.source_range.start_pos.line
+        @offset = @tok.source_range.start_pos.offset
       end
 
       # @return [Boolean] Whether or not there's more source text to lex.
