@@ -21,10 +21,7 @@ module Sass
       # @param offset [Fixnum] The 1-based character (not byte) offset in the line on
       #   which the source string starts. Used for error reporting and sourcemap
       #   building.
-      # @comment
-      #   rubocop:disable ParameterLists
       def initialize(str, filename, importer, line = 1, offset = 1)
-        # rubocop:enable ParameterLists
         @template = str
         @filename = filename
         @importer = importer
@@ -55,6 +52,15 @@ module Sass
         interp_ident
       end
 
+      # Parses a supports clause for an @import directive
+      def parse_supports_clause
+        init_scanner!
+        ss
+        clause = supports_clause
+        ss
+        clause
+      end
+
       # Parses a media query list.
       #
       # @return [Sass::Media::QueryList] The parsed query list
@@ -108,7 +114,7 @@ module Sass
           if @template.is_a?(StringScanner)
             @template
           else
-            Sass::Util::MultibyteStringScanner.new(@template.gsub("\r", ""))
+            Sass::Util::MultibyteStringScanner.new(@template.tr("\r", ""))
           end
       end
 
@@ -150,21 +156,16 @@ module Sass
         silent = text =~ %r{\A//}
         loud = !silent && text =~ %r{\A/[/*]!}
         line = @line - text.count("\n")
+        comment_start = @scanner.pos - text.length
+        index_before_line = @scanner.string.rindex("\n", comment_start) || -1
+        offset = comment_start - index_before_line
 
         if silent
           value = [text.sub(%r{\A\s*//}, '/*').gsub(%r{^\s*//}, ' *') + ' */']
         else
-          value = Sass::Engine.parse_interp(
-            text, line, @scanner.pos - text.size, :filename => @filename)
-          string_before_comment = @scanner.string[0...@scanner.pos - text.length]
-          newline_before_comment = string_before_comment.rindex("\n")
-          last_line_before_comment =
-            if newline_before_comment
-              string_before_comment[newline_before_comment + 1..-1]
-            else
-              string_before_comment
-            end
-          value.unshift(last_line_before_comment.gsub(/[^\s]/, ' '))
+          value = Sass::Engine.parse_interp(text, line, offset, :filename => @filename)
+          line_before_comment = @scanner.string[index_before_line + 1...comment_start]
+          value.unshift(line_before_comment.gsub(/[^\s]/, ' '))
         end
 
         type = if silent
@@ -174,8 +175,8 @@ module Sass
                else
                  :normal
                end
-        comment = Sass::Tree::CommentNode.new(value, type)
-        comment.line = line
+        start_pos = Sass::Source::Position.new(line, offset)
+        comment = node(Sass::Tree::CommentNode.new(value, type), start_pos)
         node << comment
       end
 
@@ -215,12 +216,12 @@ module Sass
       end
 
       def special_directive(name, start_pos)
-        sym = name.gsub('-', '_').to_sym
+        sym = name.tr('-', '_').to_sym
         DIRECTIVES.include?(sym) && send("#{sym}_directive", start_pos)
       end
 
       def prefixed_directive(name, start_pos)
-        sym = deprefix(name).gsub('-', '_').to_sym
+        sym = deprefix(name).tr('-', '_').to_sym
         PREFIXED_DIRECTIVES.include?(sym) && send("#{sym}_directive", name, start_pos)
       end
 
@@ -380,16 +381,21 @@ module Sass
         if uri
           str = sass_script(:parse_string)
           ss
+          supports = supports_clause
+          ss
           media = media_query_list
           ss
-          return node(Tree::CssImportNode.new(str, media.to_a), start_pos)
+          return node(Tree::CssImportNode.new(str, media.to_a, supports), start_pos)
         end
         ss
 
+        supports = supports_clause
+        ss
         media = media_query_list
-        if str =~ %r{^(https?:)?//} || media || use_css_import?
-          return node(Sass::Tree::CssImportNode.new(
-              Sass::Script::Value::String.quote(str), media.to_a), start_pos)
+        if str =~ %r{^(https?:)?//} || media || supports || use_css_import?
+          return node(
+            Sass::Tree::CssImportNode.new(
+              Sass::Script::Value::String.quote(str), media.to_a, supports), start_pos)
         end
 
         node(Sass::Tree::ImportNode.new(str.strip), start_pos)
@@ -549,6 +555,15 @@ module Sass
         node(node, start_pos)
       end
 
+      def supports_clause
+        return unless tok(/supports\(/i)
+        ss
+        supports = supports_condition
+        ss
+        tok!(/\)/)
+        supports
+      end
+
       def supports_condition
         supports_negation || supports_operator || supports_interpolation
       end
@@ -629,8 +644,9 @@ module Sass
       def ruleset
         start_pos = source_position
         return unless (rules = almost_any_value)
-        block(node(
-          Sass::Tree::RuleNode.new(rules, range(start_pos)), start_pos), :ruleset)
+        block(
+          node(
+            Sass::Tree::RuleNode.new(rules, range(start_pos)), start_pos), :ruleset)
       end
 
       def block(node, context)
@@ -705,8 +721,9 @@ module Sass
           selector << additional_selector
         end
 
-        block(node(
-          Sass::Tree::RuleNode.new(merge(selector), range(start_pos)), start_pos), :ruleset)
+        block(
+          node(
+            Sass::Tree::RuleNode.new(merge(selector), range(start_pos)), start_pos), :ruleset)
       end
 
       # Tries to parse a declaration, and returns the value parsed so far if it
@@ -1170,33 +1187,34 @@ module Sass
 
       def tok(rx, last_group_lookahead = false)
         res = @scanner.scan(rx)
-        if res
-          # This fixes https://github.com/nex3/sass/issues/104, which affects
-          # Ruby 1.8.7 and REE. This fix is to replace the ?= zero-width
-          # positive lookahead operator in the Regexp (which matches without
-          # consuming the matched group), with a match that does consume the
-          # group, but then rewinds the scanner and removes the group from the
-          # end of the matched string. This fix makes the assumption that the
-          # matched group will always occur at the end of the match.
-          if last_group_lookahead && @scanner[-1]
-            @scanner.pos -= @scanner[-1].length
-            res.slice!(-@scanner[-1].length..-1)
-          end
 
-          newline_count = res.count(NEWLINE)
-          if newline_count > 0
-            @line += newline_count
-            @offset = res[res.rindex(NEWLINE)..-1].size
-          else
-            @offset += res.size
-          end
+        return unless res
 
-          @expected = nil
-          if !@strs.empty? && rx != COMMENT && rx != SINGLE_LINE_COMMENT
-            @strs.each {|s| s << res}
-          end
-          res
+        # This fixes https://github.com/nex3/sass/issues/104, which affects
+        # Ruby 1.8.7 and REE. This fix is to replace the ?= zero-width
+        # positive lookahead operator in the Regexp (which matches without
+        # consuming the matched group), with a match that does consume the
+        # group, but then rewinds the scanner and removes the group from the
+        # end of the matched string. This fix makes the assumption that the
+        # matched group will always occur at the end of the match.
+        if last_group_lookahead && @scanner[-1]
+          @scanner.pos -= @scanner[-1].length
+          res.slice!(-@scanner[-1].length..-1)
         end
+
+        newline_count = res.count(NEWLINE)
+        if newline_count > 0
+          @line += newline_count
+          @offset = res[res.rindex(NEWLINE)..-1].size
+        else
+          @offset += res.size
+        end
+
+        @expected = nil
+        if !@strs.empty? && rx != COMMENT && rx != SINGLE_LINE_COMMENT
+          @strs.each {|s| s << res}
+        end
+        res
       end
 
       # Remove a vendor prefix from `str`.
