@@ -89,7 +89,7 @@ module Sass
         resolved_members = @members.map do |sel|
           next sel unless sel.is_a?(Pseudo) && sel.selector
           sel.with_selector(sel.selector.resolve_parent_refs(super_cseq, !:implicit_parent))
-        end
+        end.flatten
 
         # Parent selector only appears as the first selector in the sequence
         unless (parent = resolved_members.first).is_a?(Parent)
@@ -133,9 +133,9 @@ module Sass
           end
 
           Sequence.new(members[0...-1] +
-            [SimpleSequence.new(parent_sub + @members[1..-1], subject?)] +
+            [SimpleSequence.new(parent_sub + resolved_members[1..-1], subject?)] +
             [newline].compact)
-        end)
+          end)
       end
 
       # Non-destructively extends this selector with the extensions specified in a hash
@@ -158,12 +158,26 @@ module Sass
         seen_with_pseudo_selectors = seen.dup
 
         modified_original = false
-        members = Sass::Util.enum_with_index(self.members).map do |sel, i|
+        members = self.members.map do |sel|
           next sel unless sel.is_a?(Pseudo) && sel.selector
           next sel if seen.include?([sel])
           extended = sel.selector.do_extend(extends, parent_directives, replace, seen, !:original)
           next sel if extended == sel.selector
           extended.members.reject! {|seq| seq.has_placeholder?}
+
+          # For `:not()`, we usually want to get rid of any complex
+          # selectors because that will cause the selector to fail to
+          # parse on all browsers at time of writing. We can keep them
+          # if either the original selector had a complex selector, or
+          # the result of extending has only complex selectors,
+          # because either way we aren't breaking anything that isn't
+          # already broken.
+          if sel.normalized_name == 'not' &&
+              (sel.selector.members.none? {|seq| seq.members.length > 1} &&
+               extended.members.any? {|seq| seq.members.length == 1})
+            extended.members.reject! {|seq| seq.members.length > 1}
+          end
+
           modified_original = true
           result = sel.with_selector(extended)
           result.each {|new_sel| seen_with_pseudo_selectors << [new_sel]}
@@ -265,14 +279,14 @@ module Sass
           end
         end
 
-        our_spcs.all? do |name, pseudos|
+        our_spcs.all? do |_name, pseudos|
           pseudos.all? {|pseudo| pseudo.superselector?(their_sseq, parents)}
         end
       end
 
       # @see Simple#to_s
-      def to_s
-        res = @members.join
+      def to_s(opts = {})
+        res = @members.map {|m| m.to_s(opts)}.join
         res << '!' if subject?
         res
       end
@@ -318,12 +332,12 @@ MESSAGE
       end
 
       def _hash
-        [base, Sass::Util.set_hash(rest)].hash
+        [base, rest.hash].hash
       end
 
       def _eql?(other)
         other.base.eql?(base) && other.pseudo_elements == pseudo_elements &&
-          Sass::Util.set_eql?(other.rest, rest) && other.subject? == subject?
+          other.rest.eql?(rest) && other.subject? == subject?
       end
     end
   end
