@@ -1296,6 +1296,16 @@ SASS
 foo {
   a: 1px / 2px;
 }
+SCSS
+
+    # Regression test for issue 1787
+    assert_renders <<SASS, <<SCSS
+foo
+  a: 1px / 2px 3px
+SASS
+foo {
+  a: 1px / 2px 3px;
+}
 SCSS
   end
 
@@ -2102,6 +2112,14 @@ foo {
 SCSS
   end
 
+  def test_import_with_supports_clause
+    assert_renders(<<'SASS', <<'SCSS')
+@import url("fallback-layout.css") supports(not (display: #{$display-type}))
+SASS
+@import url("fallback-layout.css") supports(not (display: #{$display-type}));
+SCSS
+  end
+
   private
 
   def assert_sass_to_sass(sass, options = {})
